diff --git a/modules/intervals.c b/modules/intervals.c
new file mode 100644
index 0000000..e54f368
--- /dev/null
+++ b/modules/intervals.c
@@ -0,0 +1,217 @@
+/*
+    modules/intervals.c: interval training module for openchronos-ng
+
+    Copyright (C) 2014 Anthony Toft <toftat@cowshed.us>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+#include <openchronos.h>
+
+/* driver */
+#include <drivers/display.h>
+#include <drivers/buzzer.h>
+
+
+typedef struct intervalsS
+{
+	int on;
+	int off;
+} intervalsS;
+
+static intervalsS intervals;
+static uint8_t tmpVal;
+static int current;
+static char on;
+
+static void displayTime(int time)
+{
+	int seconds = time % 60;
+	int minutes = time / 60;
+
+	// display current on the top line
+	_printf(0, LCD_SEG_L1_3_2, "%02u", minutes);
+	_printf(0, LCD_SEG_L1_1_0, "%02u", seconds);
+}
+
+static void edit_on_min_sel()
+{
+	displayTime(intervals.on);
+	display_chars(0, LCD_SEG_L1_3_2, NULL, BLINK_ON);
+	display_chars(0, LCD_SEG_L2_2_0, "ON ", SEG_SET);
+	tmpVal = intervals.on / 60;
+	intervals.on -= (tmpVal * 60);
+}
+
+static void edit_on_min_dsel()
+{
+	display_chars(0, LCD_SEG_L1_3_2, NULL, BLINK_OFF);
+	intervals.on += (tmpVal * 60);
+}
+
+static void edit_on_min_set(int8_t step)
+{
+	helpers_loop(&tmpVal, 0, 99, step);
+	_printf(0, LCD_SEG_L1_3_2, "%02u", tmpVal);
+}
+
+static void edit_off_min_sel()
+{
+        displayTime(intervals.off);
+        display_chars(0, LCD_SEG_L1_3_2, NULL, BLINK_ON);
+        display_chars(0, LCD_SEG_L2_2_0, "OFF", SEG_SET);
+        tmpVal = intervals.off / 60;
+        intervals.off -= (tmpVal * 60);
+}
+
+static void edit_off_min_dsel()
+{
+        display_chars(0, LCD_SEG_L1_3_2, NULL, BLINK_OFF);
+        intervals.off += (tmpVal * 60);
+}
+
+static void edit_off_min_set(int8_t step)
+{
+        helpers_loop(&tmpVal, 0, 99, step);
+        _printf(0, LCD_SEG_L1_3_2, "%02u", tmpVal);
+}
+
+static void edit_on_sec_sel()
+{
+        displayTime(intervals.on);
+        display_chars(0, LCD_SEG_L1_1_0, NULL, BLINK_ON);
+        display_chars(0, LCD_SEG_L2_3_0, " ON ", SEG_SET);
+        tmpVal = intervals.on % 60;
+        intervals.on -= tmpVal;
+}
+
+static void edit_on_sec_dsel()
+{
+        display_chars(0, LCD_SEG_L1_1_0, NULL, BLINK_OFF);
+        intervals.on += tmpVal;
+}
+
+static void edit_on_sec_set(int8_t step)
+{
+        helpers_loop(&tmpVal, 0, 60, step);
+        _printf(0, LCD_SEG_L1_1_0, "%02u", tmpVal);
+}
+
+static void edit_off_sec_sel()
+{
+	displayTime(intervals.off);
+	display_chars(0, LCD_SEG_L1_1_0, NULL, BLINK_ON);
+	display_chars(0, LCD_SEG_L2_3_0, " OFF", SEG_SET);
+	tmpVal = intervals.off % 60;
+	intervals.off -= tmpVal;
+}
+
+static void edit_off_sec_dsel()
+{
+	display_chars(0, LCD_SEG_L1_1_0, NULL, BLINK_OFF);
+	intervals.off += tmpVal;
+}
+
+static void edit_off_sec_set(int8_t step)
+{
+	helpers_loop(&tmpVal, 0, 60, step);
+	_printf(0, LCD_SEG_L1_1_0, "%02u", tmpVal);
+}
+
+/* edit mode item table */
+static struct menu_editmode_item editModeItems[] = {
+	{edit_on_min_sel, edit_on_min_dsel, edit_on_min_set},
+	{edit_on_sec_sel, edit_on_sec_dsel, edit_on_sec_set},
+	{edit_off_min_sel, edit_off_min_dsel, edit_off_min_set},
+	{edit_off_sec_sel, edit_off_sec_dsel, edit_off_sec_set},
+	{ NULL },
+};
+
+
+static note shortbeep[] = {0x1F48, 0x000F};
+static note longbeep[] = {0x3E98, 0x000F};
+
+static void secondTick()
+{
+	current--;
+
+	switch(current)
+	{
+	case 3:
+	case 2:
+	case 1:
+		//beep
+                buzzer_play(shortbeep);
+		break;
+	case 0:
+		buzzer_play(longbeep);
+		if(on)
+		{
+			current = intervals.off;
+			display_chars(0, LCD_SEG_L2_3_0, " OFF", SEG_SET);
+		}
+		else
+		{
+			current = intervals.on;
+                        display_chars(0, LCD_SEG_L2_3_0, " ON ", SEG_SET);
+		}
+		
+		on = !on;
+		break;
+        }
+
+	displayTime(current);
+}
+
+static void activate()
+{
+	// initialize the system to give 5 seconds of rest before 
+	// starting the intervals
+	on = 0;
+	current = 5;
+	display_chars(0, LCD_SEG_L2_3_0, "WAIT", SEG_SET);
+	sys_messagebus_register(&secondTick, SYS_MSG_RTC_SECOND);
+}
+
+static void deactivate()
+{
+	sys_messagebus_unregister(&secondTick);
+}
+
+static void buttonUp()
+{
+}
+
+static void buttonDown()
+{
+}
+
+static void editModeDone()
+{
+	activate();
+}
+
+static void longStarButton()
+{
+	// deactivate the timer, it's not needed here!
+	deactivate();
+	menu_editmode_start(editModeDone, editModeItems);
+}
+
+void mod_intervals_init(void)
+{
+	intervals.on = 30;
+	intervals.off = 60;
+	menu_add_entry("INT  ", &buttonUp, &buttonDown, NULL, &longStarButton, NULL, NULL, &activate, &deactivate);
+}
diff --git a/modules/intervals.cfg b/modules/intervals.cfg
new file mode 100644
index 0000000..7f323b3
--- /dev/null
+++ b/modules/intervals.cfg
@@ -0,0 +1,4 @@
+[INTERVALS]
+name = Interval timer [EXPERIMENTAL]
+default = false 
+help = An interval timer for exercising, with an 'on' interval (for high effort level) and an 'off' interval (low intesity/recovery)
